@@ -3,8 +3,8 @@
  *
  *   (C) 2003 Dominic Morris
  *
- *   $Id: menuapp.c,v 1.49 2004/07/26 21:05:45 dom Exp $
- *   $Date: 2004/07/26 21:05:45 $
+ *   $Id: menuapp.c,v 1.52 2004/10/24 11:46:56 dom Exp $
+ *   $Date: 2004/10/24 11:46:56 $
  *
  *
  *   Implements the application
@@ -652,6 +652,8 @@ static int process_media(menu_t *menu,void *imenuapp, int sel)
     filelist_t   *entry;
     menu_t       *child;
     int           i;
+    const char    *blue_key;
+    int           has_subdirs;
 
     menu_free_dialcode(menu);
     menu_set_dialcode_selection(menu,0);
@@ -670,6 +672,7 @@ static int process_media(menu_t *menu,void *imenuapp, int sel)
         program_register_ack(dirlist->menuapp->program,REGISTER_MEDIA,media_ack,dirlist->menuapp);
         return 1;
     } else if ( entry->flags & FILE_DIR ) {
+
         /* The selection was a directory - we need to create a new menu - hah! */
         dirlist2 = new_dirlist(dirlist->menuapp);
 
@@ -685,10 +688,22 @@ static int process_media(menu_t *menu,void *imenuapp, int sel)
         menu_set_param_clearup(child,delete_dirlist);
         menu_set_dialcode_callback(child, dial_entry);
             
+	has_subdirs = 0;
         for ( i = 0; i < dirlist2->filelist_num; i++ ) {
             menu_add(child,dirlist2->filelist[i].display_name,process_media);             
+	    if (dirlist2->filelist[i].flags & FILE_DIR) {
+	    	has_subdirs = 1;
+	    }
         }
-        menu_set_colour_actions(child,tr("Back"),tr("Play dir"),tr("Play list"), NULL, media_colour_keys);
+
+        blue_key = NULL;
+#ifdef VDR_PLUGIN
+        if (!has_subdirs && is_vdr_recording(dirlist2->path)) {
+            blue_key = tr("Delete dir");
+        }
+#endif
+
+        menu_set_colour_actions(child,tr("Back"),tr("Play dir"),tr("Play list"), blue_key, media_colour_keys);
 
         menu_display(child);
         return 1; 
@@ -793,6 +808,9 @@ static int media_colour_keys(menu_t *menu, void *imenuapp, int key, int sel)
     dirlist_t     *dir = (dirlist_t *)imenuapp;
     int            i;
     char           play = TRUE;
+#ifdef VDR_PLUGIN
+    menu_t	   *child;
+#endif
 
     switch ( key ) {
     case keyRed:
@@ -823,6 +841,19 @@ static int media_colour_keys(menu_t *menu, void *imenuapp, int key, int sel)
     case keyYellow:      
         playlist_parse(dir->menuapp,dir->path,dir->filelist[sel].url);
         break;   
+
+#ifdef VDR_PLUGIN
+    case keyBlue:
+
+        child = new_menu(dir->menuapp->dongle,dir->menuapp->render,dir->menuapp->program,menu,dir,0);
+        menu_set_title(child,tr("Confirm delete"));
+            
+        menu_set_colour_actions(child,tr("Back"),tr("Delete"),NULL, NULL, recdel_colour_keys);
+
+        menu_display(child);
+        break;
+#endif
+
     default:
         break;
     }
@@ -1038,12 +1069,22 @@ static int media_keys(void *ptr, int code)
         break;
     case keySkip:
         if (  ( streamtype & MEDIA_LIVE ) == 0 ) {
-            dongle_send_message(menuapp->dongle,RDC_STOP);
+            dongle_send_message(menuapp->dongle,RDC_SKIP);
+        }
+        break;
+    case keyReplay:
+        if (  ( streamtype & MEDIA_LIVE ) == 0 ) {
+            dongle_send_message(menuapp->dongle,RDC_BACK);
+        }
+        break;
+    case keyYellow:
+        if (  ( streamtype & MEDIA_LIVE ) == 0 ) {
+            dongle_send_message(menuapp->dongle,RDC_SKIP);
         } else {
             return 0;   /* Continue with the menus */
         }
         break;
-    case keyReplay:
+    case keyGreen:
         if (  ( streamtype & MEDIA_LIVE ) == 0 ) {
             dongle_send_message(menuapp->dongle,RDC_BACK);
         } else {
