@@ -1,8 +1,8 @@
 /*
  *  MediaMVP Output Device for VDR
  *
- *  $Id: mvposd.c,v 1.2 2004/05/22 16:41:27 dom Exp $ 
- *  $Date: 2004/05/22 16:41:27 $
+ *  $Id: mvposd.c,v 1.4 2004/05/27 19:05:44 dom Exp $ 
+ *  $Date: 2004/05/27 19:05:44 $
  *
  *  This does the OSD
  *
@@ -39,7 +39,6 @@ void cMvpOsd::Flush(void)
     tColor   tot = 0;
     bool     upd = false;
 
-    printf("Flush\n");
     for ( int i = 0; ( Bitmap = GetBitmap(i)) != NULL; i++ ) {
         int  x1 = 0, y1 = 0, x2 = 0, y2 = 0;
         if ( Bitmap->Dirty(x1,y2,x2,y2) ) {
@@ -50,15 +49,18 @@ void cMvpOsd::Flush(void)
                     if ( tot == 0 && c )
                         tot |= c;
 
-                    surface_set_pixel(sfc,xp +  Bitmap->X0() + Left(),yp + Top() + Bitmap->Y0(), c & 0x00FFFFFF );                       
+                    surface_set_pixel(sfc,xp +  Bitmap->X0() + Left(),yp + Top() + Bitmap->Y0(), c );                       
                 }
             }
         }
     }
     if ( tot )
         program->SendEvent(MEVT_MENU_ON);
-    else
+    else {
+        surface_clear(sfc,0x00000000);
+        program->SendEvent(MEVT_UPDATE);
         program->SendEvent(MEVT_MENU_OFF);
+    }
 
     if ( upd == true )
         program->SendEvent(MEVT_UPDATE);
