@@ -3,7 +3,7 @@
  *
  * See the README file for copyright information and how to reach the author.
  *
- * $Id: i18n.c,v 1.9 2004/05/11 20:02:54 dom Exp $
+ * $Id: i18n.c,v 1.10 2004/10/17 20:57:06 dom Exp $
  */
 
 #include "i18n.h"
@@ -26,7 +26,11 @@ const tI18nPhrase Phrases[] = {
       "",                             // Magyar
       "",                             // Catala
 #if VDRVERSNUM >= 10300
-      ""                              // Russian
+      "",                             // Russian
+#endif
+#if VDRVERSNUM >= 10313
+      "",                             // Croatian
+      "",                             // Estonian
 #endif
     },
     { "MediaMVP GUI Port",            // English
@@ -46,7 +50,11 @@ const tI18nPhrase Phrases[] = {
       "",                             // Magyar
       "",                             // Catala
 #if VDRVERSNUM >= 10300
-      ""                              // Russian
+      "",                             // Russian
+#endif
+#if VDRVERSNUM >= 10313
+      "",                             // Croatian
+      "",                             // Estonian
 #endif
     },
     { "MediaMVP Stream Port",         // English
@@ -66,7 +74,11 @@ const tI18nPhrase Phrases[] = {
       "",                             // Magyar
       "",                             // Catala
 #if VDRVERSNUM >= 10300
-      ""                              // Russian
+      "",                             // Russian
+#endif
+#if VDRVERSNUM >= 10313
+      "",                             // Croatian
+      "",                             // Estonian
 #endif
     },
    { "MediaMVP dongle.bin version",   // English
@@ -86,7 +98,11 @@ const tI18nPhrase Phrases[] = {
       "",                             // Magyar
       "",                             // Catala
 #if VDRVERSNUM >= 10300
-      ""                              // Russian
+      "",                             // Russian
+#endif
+#if VDRVERSNUM >= 10313
+      "",                             // Croatian
+      "",                             // Estonian
 #endif
     },
    { "Total Screen Width",            // English
@@ -106,7 +122,11 @@ const tI18nPhrase Phrases[] = {
       "",                             // Magyar
       "",                             // Catala
 #if VDRVERSNUM >= 10300
-      ""                              // Russian
+      "",                             // Russian
+#endif
+#if VDRVERSNUM >= 10313
+      "",                             // Croatian
+      "",                             // Estonian
 #endif
     },
    { "Total Screen Depth",            // English
@@ -126,7 +146,11 @@ const tI18nPhrase Phrases[] = {
       "",                             // Magyar
       "",                             // Catala
 #if VDRVERSNUM >= 10300
-      ""                              // Russian
+      "",                             // Russian
+#endif
+#if VDRVERSNUM >= 10313
+      "",                             // Croatian
+      "",                             // Estonian
 #endif
     },
    { "GUI Screen Width",              // English
@@ -146,7 +170,11 @@ const tI18nPhrase Phrases[] = {
       "",                             // Magyar
       "",                             // Catala
 #if VDRVERSNUM >= 10300
-      ""                              // Russian
+      "",                             // Russian
+#endif
+#if VDRVERSNUM >= 10313
+      "",                             // Croatian
+      "",                             // Estonian
 #endif
     },
    { "GUI Screen Depth",              // English
@@ -166,7 +194,11 @@ const tI18nPhrase Phrases[] = {
       "",                             // Magyar
       "",                             // Catala
 #if VDRVERSNUM >= 10300
-      ""                              // Russian
+      "",                             // Russian
+#endif
+#if VDRVERSNUM >= 10313
+      "",                             // Croatian
+      "",                             // Estonian
 #endif
     },
     { "MediaMVP",                     // English
@@ -186,7 +218,11 @@ const tI18nPhrase Phrases[] = {
       "",                             // Magyar
       "",                             // Catala
 #if VDRVERSNUM >= 10300
-      ""                              // Russian
+      "",                             // Russian
+#endif
+#if VDRVERSNUM >= 10313
+      "",                             // Croatian
+      "",                             // Estonian
 #endif
     },
     { "Channels",                     // English
@@ -206,7 +242,11 @@ const tI18nPhrase Phrases[] = {
       "",                             // Magyar
       "",                             // Catala
 #if VDRVERSNUM >= 10300
-      ""                              // Russian
+      "",                             // Russian
+#endif
+#if VDRVERSNUM >= 10313
+      "",                             // Croatian
+      "",                             // Estonian
 #endif
     },
     { "Internet Radio",               // English
@@ -226,7 +266,11 @@ const tI18nPhrase Phrases[] = {
       "",                             // Magyar
       "",                             // Catala
 #if VDRVERSNUM >= 10300
-      ""                              // Russian
+      "",                             // Russian
+#endif
+#if VDRVERSNUM >= 10313
+      "",                             // Croatian
+      "",                             // Estonian
 #endif
     },
     { "Other Videos",                 // English
@@ -246,7 +290,11 @@ const tI18nPhrase Phrases[] = {
       "",                             // Magyar
       "",                             // Catala
 #if VDRVERSNUM >= 10300
-      ""                              // Russian
+      "",                             // Russian
+#endif
+#if VDRVERSNUM >= 10313
+      "",                             // Croatian
+      "",                             // Estonian
 #endif
     },
     { "Music",                        // English
@@ -266,7 +314,11 @@ const tI18nPhrase Phrases[] = {
       "",                             // Magyar
       "",                             // Catala
 #if VDRVERSNUM >= 10300
-      ""                              // Russian
+      "",                             // Russian
+#endif
+#if VDRVERSNUM >= 10313
+      "",                             // Croatian
+      "",                             // Estonian
 #endif
     },
     { "Settings",                     // English
@@ -286,7 +338,11 @@ const tI18nPhrase Phrases[] = {
       "",                             // Magyar
       "",                             // Catala
 #if VDRVERSNUM >= 10300
-      ""                              // Russian
+      "",                             // Russian
+#endif
+#if VDRVERSNUM >= 10313
+      "",                             // Croatian
+      "",                             // Estonian
 #endif
     },
     { "NTSC",                         // English
@@ -306,7 +362,11 @@ const tI18nPhrase Phrases[] = {
       "",                             // Magyar
       "",                             // Catala
 #if VDRVERSNUM >= 10300
-      ""                              // Russian
+      "",                             // Russian
+#endif
+#if VDRVERSNUM >= 10313
+      "",                             // Croatian
+      "",                             // Estonian
 #endif
     },
     { "PAL",                          // English
@@ -326,7 +386,11 @@ const tI18nPhrase Phrases[] = {
       "",                             // Magyar
       "",                             // Catala
 #if VDRVERSNUM >= 10300
-      ""                              // Russian
+      "",                             // Russian
+#endif
+#if VDRVERSNUM >= 10313
+      "",                             // Croatian
+      "",                             // Estonian
 #endif
     },
     { "None",                         // English
@@ -346,7 +410,11 @@ const tI18nPhrase Phrases[] = {
       "",                             // Magyar
       "",                             // Catala
 #if VDRVERSNUM >= 10300
-      ""                              // Russian
+      "",                             // Russian
+#endif
+#if VDRVERSNUM >= 10313
+      "",                             // Croatian
+      "",                             // Estonian
 #endif
     },
    { "Low",                           // English
@@ -366,7 +434,11 @@ const tI18nPhrase Phrases[] = {
       "",                             // Magyar
       "",                             // Catala
 #if VDRVERSNUM >= 10300
-      ""                              // Russian
+      "",                             // Russian
+#endif
+#if VDRVERSNUM >= 10313
+      "",                             // Croatian
+      "",                             // Estonian
 #endif
     },
    { "Medium",                        // English
@@ -386,7 +458,11 @@ const tI18nPhrase Phrases[] = {
       "",                             // Magyar
       "",                             // Catala
 #if VDRVERSNUM >= 10300
-      ""                              // Russian
+      "",                             // Russian
+#endif
+#if VDRVERSNUM >= 10313
+      "",                             // Croatian
+      "",                             // Estonian
 #endif
     },
     { "High",                         // English
@@ -406,7 +482,11 @@ const tI18nPhrase Phrases[] = {
       "",                             // Magyar
       "",                             // Catala
 #if VDRVERSNUM >= 10300
-      ""                              // Russian
+      "",                             // Russian
+#endif
+#if VDRVERSNUM >= 10313
+      "",                             // Croatian
+      "",                             // Estonian
 #endif
     },
     { "RGB Detected",                 // English
@@ -426,7 +506,11 @@ const tI18nPhrase Phrases[] = {
       "",                             // Magyar
       "",                             // Catala
 #if VDRVERSNUM >= 10300
-      ""                              // Russian
+      "",                             // Russian
+#endif
+#if VDRVERSNUM >= 10313
+      "",                             // Croatian
+      "",                             // Estonian
 #endif
     },
     { "SVideo",                       // English
@@ -446,7 +530,11 @@ const tI18nPhrase Phrases[] = {
       "",                             // Magyar
       "",                             // Catala
 #if VDRVERSNUM >= 10300
-      ""                              // Russian
+      "",                             // Russian
+#endif
+#if VDRVERSNUM >= 10313
+      "",                             // Croatian
+      "",                             // Estonian
 #endif
     },
     { "Composite",                    // English
@@ -466,7 +554,11 @@ const tI18nPhrase Phrases[] = {
       "",                             // Magyar
       "",                             // Catala
 #if VDRVERSNUM >= 10300
-      ""                              // Russian
+      "",                             // Russian
+#endif
+#if VDRVERSNUM >= 10313
+      "",                             // Croatian
+      "",                             // Estonian
 #endif
     },
     { "RGB/Composite",                // English
@@ -486,7 +578,11 @@ const tI18nPhrase Phrases[] = {
       "",                             // Magyar
       "",                             // Catala
 #if VDRVERSNUM >= 10300
-      ""                              // Russian
+      "",                             // Russian
+#endif
+#if VDRVERSNUM >= 10313
+      "",                             // Croatian
+      "",                             // Estonian
 #endif
     },
     { "TV Mode:",                     // English
@@ -506,7 +602,11 @@ const tI18nPhrase Phrases[] = {
       "",                             // Magyar
       "",                             // Catala
 #if VDRVERSNUM >= 10300
-      ""                              // Russian
+      "",                             // Russian
+#endif
+#if VDRVERSNUM >= 10313
+      "",                             // Croatian
+      "",                             // Estonian
 #endif
     },
     { "Output:",                      // English
@@ -526,7 +626,11 @@ const tI18nPhrase Phrases[] = {
       "",                             // Magyar
       "",                             // Catala
 #if VDRVERSNUM >= 10300
-      ""                              // Russian
+      "",                             // Russian
+#endif
+#if VDRVERSNUM >= 10313
+      "",                             // Croatian
+      "",                             // Estonian
 #endif
     },
     { "Flicker Control:",             // English
@@ -546,7 +650,11 @@ const tI18nPhrase Phrases[] = {
       "",                             // Magyar
       "",                             // Catala
 #if VDRVERSNUM >= 10300
-      ""                              // Russian
+      "",                             // Russian
+#endif
+#if VDRVERSNUM >= 10313
+      "",                             // Croatian
+      "",                             // Estonian
 #endif
     },
     { "Aspect Ratio:",                // English
@@ -566,7 +674,11 @@ const tI18nPhrase Phrases[] = {
       "",                             // Magyar
       "",                             // Catala
 #if VDRVERSNUM >= 10300
-      ""                              // Russian
+      "",                             // Russian
+#endif
+#if VDRVERSNUM >= 10313
+      "",                             // Croatian
+      "",                             // Estonian
 #endif
     },
     { "Cancel changes",               // English
@@ -586,7 +698,11 @@ const tI18nPhrase Phrases[] = {
       "",                             // Magyar
       "",                             // Catala
 #if VDRVERSNUM >= 10300
-      ""                              // Russian
+      "",                             // Russian
+#endif
+#if VDRVERSNUM >= 10313
+      "",                             // Croatian
+      "",                             // Estonian
 #endif
     },
     { "Save settings (may take a while)",  // English
@@ -606,7 +722,11 @@ const tI18nPhrase Phrases[] = {
       "",                             // Magyar
       "",                             // Catala
 #if VDRVERSNUM >= 10300
-      ""                              // Russian
+      "",                             // Russian
+#endif
+#if VDRVERSNUM >= 10313
+      "",                             // Croatian
+      "",                             // Estonian
 #endif
     },
     { "Play list",                    // English
@@ -626,7 +746,11 @@ const tI18nPhrase Phrases[] = {
       "",                             // Magyar
       "",                             // Catala
 #if VDRVERSNUM >= 10300
-      ""                              // Russian
+      "",                             // Russian
+#endif
+#if VDRVERSNUM >= 10313
+      "",                             // Croatian
+      "",                             // Estonian
 #endif
     },
     { "Play dir",                     // English
@@ -646,7 +770,11 @@ const tI18nPhrase Phrases[] = {
       "",                             // Magyar
       "",                             // Catala
 #if VDRVERSNUM >= 10300
-      ""                              // Russian
+      "",                             // Russian
+#endif
+#if VDRVERSNUM >= 10313
+      "",                             // Croatian
+      "",                             // Estonian
 #endif
     },
     { "Debug Level",                  // English
@@ -666,7 +794,11 @@ const tI18nPhrase Phrases[] = {
       "",                             // Magyar
       "",                             // Catala
 #if VDRVERSNUM >= 10300
-      ""                              // Russian
+      "",                             // Russian
+#endif
+#if VDRVERSNUM >= 10313
+      "",                             // Croatian
+      "",                             // Estonian
 #endif
     },
     { "Pictures",                     // English
@@ -686,7 +818,11 @@ const tI18nPhrase Phrases[] = {
       "",                             // Magyar
       "",                             // Catala
 #if VDRVERSNUM >= 10300
-      ""                              // Russian
+      "",                             // Russian
+#endif
+#if VDRVERSNUM >= 10313
+      "",                             // Croatian
+      "",                             // Estonian
 #endif
     },
     { "News Feeds",                   // English
@@ -706,7 +842,11 @@ const tI18nPhrase Phrases[] = {
       "",                             // Magyar
       "",                             // Catala
 #if VDRVERSNUM >= 10300
-      ""                              // Russian
+      "",                             // Russian
+#endif
+#if VDRVERSNUM >= 10313
+      "",                             // Croatian
+      "",                             // Estonian
 #endif
     },
     { "Screensaver Enabled",          // English
@@ -726,7 +866,11 @@ const tI18nPhrase Phrases[] = {
       "",                             // Magyar
       "",                             // Catala
 #if VDRVERSNUM >= 10300
-      ""                              // Russian
+      "",                             // Russian
+#endif
+#if VDRVERSNUM >= 10313
+      "",                             // Croatian
+      "",                             // Estonian
 #endif
     },
    { "Switch standards",              // English
@@ -746,7 +890,11 @@ const tI18nPhrase Phrases[] = {
       "",                             // Magyar
       "",                             // Catala
 #if VDRVERSNUM >= 10300
-      ""                              // Russian
+      "",                             // Russian
+#endif
+#if VDRVERSNUM >= 10313
+      "",                             // Croatian
+      "",                             // Estonian
 #endif
     },
     { NULL }
