@@ -3,7 +3,7 @@
  *
  * See the README file for copyright information and how to reach the author.
  *
- * $Id: mediamvp.c,v 1.7 2004/05/11 20:02:55 dom Exp $
+ * $Id: mediamvp.c,v 1.8 2004/06/08 08:58:08 dom Exp $
  */
 
 #include "mediamvp.h"
@@ -84,30 +84,7 @@ cMenuSetupPage *cPluginMediamvp::SetupMenu(void)
 
 bool cPluginMediamvp::SetupParse(const char *Name, const char *Value)
 {
-    if ( strcmp(Name,"stream_port") == 0 ) {
-        MediamvpSetup.stream_port = atoi(Value);
-    } else if ( strcmp(Name,"gui_port") == 0 ) {
-        MediamvpSetup.gui_port = atoi(Value);
-    } else if ( strcmp(Name,"dongle_version") == 0 ) {
-        MediamvpSetup.dongle_version = atoi(Value);
-    } else if ( strcmp(Name,"screen_width") == 0 ) {
-        c_screen_width = atoi(Value);
-    } else if ( strcmp(Name,"screen_depth") == 0 ) {
-        c_screen_depth = atoi(Value);
-    } else if ( strcmp(Name,"gui_width") == 0 ) {
-        c_gui_width = atoi(Value);
-    } else if ( strcmp(Name,"gui_depth") == 0 ) {
-        c_gui_depth = atoi(Value);
-    } else if ( strcmp(Name,"debug_level") == 0 ) {
-        MediamvpSetup.debug_level = atoi(Value);
-    } else if ( strcmp(Name,"screensaver") == 0 ) {
-        c_screensaver = atoi(Value);
-    } else if ( strcmp(Name,"standardswitch") == 0 ) {
-        c_standard_switch = atoi(Value);
-        return false;
-    }
-
-    return true;
+    return ConfigParse(Name,Value);
 }
 
 VDRPLUGINCREATOR(cPluginMediamvp); // Don't touch this!
