@@ -4,8 +4,8 @@
  *
  *   (C) 2003 Dominic Morris
  *
- *   $Id: menuapp-vdr.c,v 1.8 2004/07/27 19:11:27 dom Exp $
- *   $Date: 2004/07/27 19:11:27 $
+ *   $Id: menuapp-vdr.c,v 1.9 2004/10/15 11:46:48 dom Exp $
+ *   $Date: 2004/10/15 11:46:48 $
  *
  *
  *   Contains vdr specific functionality for the menuapp
@@ -554,6 +554,7 @@ int  media_keys_vdr(menuapp_t *menuapp,int code)
                     snprintf(buf,sizeof(buf),"%s%s",VDRURL,newchannel);
                     menuapp->current_media = strdup(buf);
                     menuapp->paused = FALSE;
+		    dongle_send_message(menuapp->dongle,RDC_STOP);
                     dongle_send_play(menuapp->dongle,buf);
                 }
             }
@@ -616,5 +617,69 @@ static filelist_t *plugin_file_scan(char *filename, int *scanned)
     return list;    
 }
 
+static cRecording* find_recording(const char *dirname) {
+    char          dirpath[PATH_MAX];
+    char          recpath[PATH_MAX];
+
+    if (realpath(dirname,dirpath)) { /* recording does exist */
+        for (cRecording *recording = Recordings.First(); recording; recording = Recordings.Next(recording)) {
+            /* search for recordings comparing real paths */
+            if (realpath( recording->FileName(), recpath ) && strcmp(dirpath, recpath) == 0) {
+                return recording;
+            }
+        }
+    }
+
+    return NULL;
+}
+
+
+
+static int is_vdr_recording(const char *dirname) {
+    char    *ptr;
+    if ( ( ptr = strrchr(dirname,'.') ) != NULL ) {
+        if ( strcasecmp(ptr,".rec") == 0 && find_recording(dirname) ) {
+            return 1;
+        }
+    }
+    return 0;  	
+}
+
+
+static int recdel_colour_keys(menu_t *menu, void *imenuapp, int key, int sel)
+{
+    dirlist_t     *dir = (dirlist_t *)imenuapp;
+    cRecording    *recording;
+    menu_t        *p_menu;
+    menu_t        *pp_menu;
+    menu_t        *ppp_menu;
+
+    switch ( key ) {
+    case keyRed:
+        return 0;
+    case keyGreen:       /* Really delete the recording */
+        recording = find_recording(dir->path);
+        if (recording) {
+            recording->Delete();
+
+            /* Delete this menu, it's parent, and it's parent's parent */
+            p_menu = menu_parent(menu);
+            pp_menu = menu_parent(p_menu);
+            ppp_menu = menu_parent(pp_menu);
+            delete_menu(menu);
+            delete_menu(p_menu);
+            delete_menu(pp_menu);
+
+            menu_display(ppp_menu);
+            return 1; /* important, menu is invalid now */
+        }
+
+        break;
+    default:
+        break;
+    }
+
+    return 1;     /* Carry on displaying this menu */
+}
 
 
