@@ -3,8 +3,8 @@
  *
  *   (C) 2003 Dominic Morris
  *
- *   $Id: url_http.c,v 1.12 2004/05/07 19:27:25 dom Exp $
- *   $Date: 2004/05/07 19:27:25 $
+ *   $Id: url_http.c,v 1.13 2004/10/24 11:37:37 dom Exp $
+ *   $Date: 2004/10/24 11:37:37 $
  *
  *
  *   Deals with opening a http connection and fobbing off playlist detection
@@ -31,6 +31,7 @@ typedef struct {
     char          *location;
     char          *name;
     int            fd;
+    astrip_t       strip;
 } httpfile_t;
 
 static fops_t          http_fops = {
@@ -98,6 +99,9 @@ static void *http_open(char *url, int *type,fops_t **fops_ptr,readready_cb cb, v
     httpfile->cb_ptr = cb_ptr;
     httpfile->cb = cb;
     httpfile->name = icy_name;
+    httpfile->strip.tmplen = 0;
+    httpfile->strip.offset = 0;
+    httpfile->strip.pid = 0xC1;
 
     /* Obey the content type from the server if we got one */
     if ( content_type != -1 ) {
@@ -163,14 +167,19 @@ static off_t http_seek(void *ptr,off_t offset, int whence)
 static int http_read(void *ptr, unsigned char *buf, size_t bufsize)
 {
     httpfile_t  *file = (httpfile_t*)ptr;
+    int          ret = read(file->fd,buf,bufsize);
 
-    return read(file->fd,buf,bufsize);
+    audio_strip(&file->strip,buf,ret);
+
+    return ret;
 }
 
 
 
 
 
+
+
 /* HTTP stuff is stolen from mpegtools/ctools.c */
 static void write_all (int fd, uint8_t *data, int length)
 {
