@@ -3,8 +3,8 @@
  *
  *   (C) 2003 Dominic Morris
  *
- *   $Id: vdrrecurl.c,v 1.9 2004/08/28 12:38:14 dom Exp $
- *   $Date: 2004/08/28 12:38:14 $
+ *   $Id: vdrrecurl.c,v 1.11 2004/10/24 11:37:53 dom Exp $
+ *   $Date: 2004/10/24 11:37:53 $
  *
  *
  *   Handle the vdrrecurl:// URL type
@@ -28,8 +28,9 @@ static fops_t vdrrecurl_fops = {
 cMediamvpVdrRecURL::cMediamvpVdrRecURL()
 {
     fd = -1;
-    tmplen = 0;
-    offset = 0;
+    strip.tmplen = 0;
+    strip.offset = 0;
+    strip.pid = 0xC1;
     name = NULL;
 }
 
@@ -198,50 +199,7 @@ int cMediamvpVdrRecURL::sRead(void *ptr, unsigned char *buf, size_t buflen)
     /* Read data into the buffer */
     ret = vdrrecurl->Read(buf,buflen);
 
-
-    /* We saved the last few bytes of the last read since there wasn't
-       enough there for an mpeg header, so do a bit of copying around the
-       place to try and find the header info
-    */
-    if ( vdrrecurl->tmplen > 0 && ret > 6 ) {
-        memcpy(vdrrecurl->tmp + vdrrecurl->tmplen,buf,6);
-        unsigned char *lbuf = vdrrecurl->tmp;
-        unsigned char *modify = buf - vdrrecurl->tmplen;
-
-        if ( lbuf[0] == 0x00 && lbuf[1] == 0x00 && lbuf[2] == 0x01 && lbuf[3] == 0xC1 ) {
-            modify[3] = 0;
-        }
-    }
-    vdrrecurl->tmplen = 0;
-
-
-    /* Lets try and strip out any additional audio tracks here */
-    if ( ret > vdrrecurl->offset + 6) {
-        for ( i = vdrrecurl->offset; i < ret - 6; i++ ) {
-            if ( buf[i] == 0x00 && buf[i+1] == 0x00 && buf[i + 2] == 0x01 ) {
-                uchar c = buf[i+3];
-                int l = buf[i + 4] * 256 + buf[i + 5] + 6;           
-                if ( c == 0xC1  ) {
-                    buf[i+3] = 0xB0;
-                }
-                
-                if ( ( c >= 0xE0 && c <= 0xEF ) || ( c >= 0xC0 || c <= 0xCF ) ) {
-                    if ( l ) 
-                        i += l -1;
-                }
-            }
-        }
-        vdrrecurl->offset = 0;
-    }
-   
-    if ( i > 0 &&  i <= ret ) {
-        --i;  /* We incremented at top of loop */
-        memcpy(vdrrecurl->tmp + vdrrecurl->tmplen,&buf[i],(ret - i) );
-        vdrrecurl->tmplen += (ret -  i) ;
-    } else {
-        vdrrecurl->offset = i - ret;
-    }
-      
+    audio_strip(&vdrrecurl->strip,buf,ret);
 
     return ret;
 }
