@@ -3,8 +3,8 @@
  *
  *   (C) 2003 Dominic Morris
  *
- *   $Id: vdrrecurl.h,v 1.4 2004/07/11 16:13:38 dom Exp $
- *   $Date: 2004/07/11 16:13:38 $
+ *   $Id: vdrrecurl.h,v 1.5 2004/10/24 11:39:03 dom Exp $
+ *   $Date: 2004/10/24 11:39:03 $
  *
  *
  *   Handle the vdr:// URL type
@@ -19,10 +19,8 @@ private:
     int                   fd; /* Current file being read */
     int                   curfile; /* Current file */
     char                 *name;
-    size_t                offset;
-    char                  filename[FILENAME_MAX+1];  /* Directory where file is */
-    unsigned char                  tmp[100];
-    size_t                   tmplen;
+    astrip_t              strip;
+    char                  filename[FILENAME_MAX+1];  /* Directory where file is */  
     void OpenFile();
 
 public:
