@@ -3,8 +3,8 @@
  *
  *   (C) 2003 Dominic Morris
  *
- *   $Id: vdrurl.c,v 1.13 2004/05/08 10:29:04 dom Exp $
- *   $Date: 2004/05/08 10:29:04 $
+ *   $Id: vdrurl.c,v 1.14 2004/10/15 11:42:46 dom Exp $
+ *   $Date: 2004/10/15 11:42:46 $
  *
  *
  *   Handle the vdr:// URL type
@@ -101,6 +101,12 @@ void *cMediamvpVdrURL::Open(char *name, int *type, fops_t **fops, readready_cb c
         return NULL;
     }
 
+    /* If there's no pids defined then don't try to play it */
+    if ( (Channel->Vpid() == 0 || Channel->Vpid() == 1 || Channel->Vpid() == 0x1fff ) && Channel->Apid1() == 0) {
+        delete vdrurl;
+        return NULL;
+    }
+
     if ( Channel->Vpid() == 0 || Channel->Vpid() == 1 || Channel->Vpid() == 0x1fff ) {
         *type = MEDIA_MP3 | MEDIA_SOCKET | MEDIA_LIVE;
     } else {
