@@ -1,3 +1,15 @@
+/*
+ *   MediaMVP Server Widget Library
+ *
+ *   (C) 2004 Dave Kelly
+ *
+ *   $Id: label.c,v 1.7 2004/08/30 08:55:24 ravelox Exp $
+ *   $Date: 2004/08/30 08:55:24 $
+ *
+ *   Window handling
+ *
+ */
+
 #include "mvpwindow.h"
 
 #if 0
@@ -6,14 +18,37 @@
 #define DEBUG(xxx,...)
 #endif
 
-struct _label {
+static void label_set_font(window_t *label, font_t *font);
+static font_t *label_get_font(window_t *label);
+static void label_set_fgcol(window_t *label, uint32_t rgb);
+static void label_set_bgcol(window_t *label, uint32_t rgb);
+static uint32_t label_get_fgcol(window_t *label);
+static uint32_t label_get_bgcol(window_t *label);
+
+static attrib_fns_t label_fns = {
+	0,
+	NULL,
+	NULL,
+	NULL,
+	label_set_font,
+	label_set_fgcol,
+	label_set_bgcol,
+	NULL,
+	NULL,
+	NULL,
+	label_get_font,
+	label_get_fgcol,
+	label_get_bgcol
+};
+
+typedef struct  {
 	char *text;
 	uint32_t fgcol;
 	uint32_t bgcol;
 	font_t *font;
 	char align;
 	char valign;
-};
+} label_t;
 
 static void     label_print(window_t *label, int x, int y, int maxx,  char *text);
 static void     label_printchar(window_t *label, int x, int y, glyph_t *glyph);
@@ -39,11 +74,10 @@ static int label_calc_x(window_t *label, char *text)
 	text_width = font_get_textwidth(data->font, text);
 
 	switch(data->align) {
-		case LABEL_ALIGN_CENTER:
+		case LABEL_ALIGN_CENTRE:
 			x = (label_width / 2) - (text_width / 2);
 			break;
 		case LABEL_ALIGN_RIGHT:
-			fprintf(stderr, "LABEL_ALIGN_RIGHT: %d %d %d\n", label_width, text_width, window_get_xoffset(label));
 			x = label_width - text_width - window_get_xoffset(label);
 			break;
 		case LABEL_ALIGN_LEFT:
@@ -56,7 +90,6 @@ static int label_calc_x(window_t *label, char *text)
 		x = 0;
 	}
 
-	fprintf(stderr, "Calc X: %d\n", x);
 	return x;
 }
 
@@ -68,7 +101,6 @@ static void draw_label(window_t *label)
 	char *label_text, *ptr, *current_line;
 	int num_lines = 1;
 
-	fprintf(stderr, "draw_label\n");
 	if(window_get_type(label) != WINDOW_LABEL) {
 		return;
 	}
@@ -87,9 +119,8 @@ static void draw_label(window_t *label)
 		num_lines++;
 		ptr = strchr(ptr, '\n');
 	}
-	fprintf(stderr, "Number of lines: %d\n", num_lines);
 
-	surface_clear(window_get_contents(label), data->bgcol);
+	window_clear(label, data->bgcol);
 	
 	height = window_get_height(label);
 
@@ -133,8 +164,8 @@ window_t *new_label(window_t *parent, int x, int y, int width, int height, char
 	window_t *label;
 	label_t *data;
 
-	Dprintf(DEBUG, "new_label\n");
-	label = new_window(parent, x, y, width, height);
+	label = new_window(parent, WINDOW_LABEL, x, y, width, height);
+	window_set_attrib_fns(label, &label_fns);
 	data = (label_t *)malloc(sizeof(label_t));
 
 	data->text = (char *)strdup(text);
@@ -144,7 +175,7 @@ window_t *new_label(window_t *parent, int x, int y, int width, int height, char
 	data->align = 0;
 	data->valign = 0;
 
-	window_set_type(label, WINDOW_LABEL);
+	window_set_name(label,  text);
 	window_set_data(label, data);
 	window_set_draw_func(label, draw_label);
 	window_set_delete_func(label, delete_label_data);
@@ -157,7 +188,7 @@ window_t *new_label(window_t *parent, int x, int y, int width, int height, char
 	return label;
 }
 
-void label_set_font(window_t *label, font_t *font)
+static void label_set_font(window_t *label, font_t *font)
 {
 	label_t *data;
 
@@ -173,7 +204,7 @@ void label_set_font(window_t *label, font_t *font)
 	window_mark_dirty(label);
 }
 
-font_t *label_get_font(window_t *label)
+static font_t *label_get_font(window_t *label)
 {
 	label_t *data;
 
@@ -188,7 +219,7 @@ font_t *label_get_font(window_t *label)
     return data->font;
 }
 
-void label_set_fgcol(window_t *label, uint32_t rgb)
+static void label_set_fgcol(window_t *label, uint32_t rgb)
 {
 	label_t *data;
 
@@ -220,7 +251,7 @@ void label_set_bgcol(window_t *label, uint32_t rgb)
 	window_mark_dirty(label);
 }
 
-uint32_t label_get_fgcol(window_t *label)
+static uint32_t label_get_fgcol(window_t *label)
 {
 	label_t *data;
 
@@ -235,6 +266,21 @@ uint32_t label_get_fgcol(window_t *label)
 	return data->fgcol;
 }
 
+static uint32_t label_get_bgcol(window_t *label)
+{
+	label_t *data;
+
+	if(window_get_type(label) != WINDOW_LABEL) {
+		return 0;
+	}
+
+	if(! (data = (label_t *)window_get_data(label)) ) {
+		return 0;
+	}
+
+	return data->bgcol;
+}
+
 static void label_print(window_t *label, int x, int y, int maxwidth, char *text)
 {
 	label_t *data;
@@ -250,7 +296,6 @@ static void label_print(window_t *label, int x, int y, int maxwidth, char *text)
 		return;
 	}
 
-	Dprintf(DEBUG, "label_print(%s)\n", text);
     /* Check to see if a font is defined */
     if(! data->font) {
         Dprintf(ERROR, "No font defined for label\n");
@@ -261,7 +306,6 @@ static void label_print(window_t *label, int x, int y, int maxwidth, char *text)
         switch ( *text ) {
         case '\t':        /* Do some nasty stuff to calculate tab stops,
                              only really works for a full display */
-            Dprintf(DEBUG, "label_print(tabstop)\n");
             glyph_set_height(&nbsp, font_get_height(data->font));
             while ( x + 1 < ( ( x / tabwidth ) + 1 ) * tabwidth && x < maxwidth ) {
                 label_printchar(label,x,y, &nbsp);
@@ -281,7 +325,6 @@ static void label_print(window_t *label, int x, int y, int maxwidth, char *text)
             break;
 			*/
         default:
-            Dprintf(DEBUG,  "label_print(%c)\n", *(unsigned char *)text);
             if(font_is_defined(data->font, *(unsigned char *)text)) {
                 glyph = font_get_glyph(data->font, *(unsigned char *)text);
                 width = glyph_get_width(glyph);
@@ -312,8 +355,6 @@ static void label_printchar(window_t *label,int x, int y, glyph_t *glyph)
 		return;
 	}
 
-	Dprintf(DEBUG, "label_printchar\n");
-
     bitmap = glyph_get_bitmap(glyph);
 
     width = glyph_get_width(glyph);
@@ -344,8 +385,6 @@ void label_set_align(window_t *label, int align)
 		return;
 	}
 
-	fprintf(stderr, "label_set_align(%d)\n", align);
-
 	data->align = align;
 
 	window_mark_dirty(label);
@@ -363,7 +402,6 @@ void label_set_valign(window_t *label, int valign)
 		return;
 	}
 
-	fprintf(stderr, "label_set_valign(%d)\n", valign);
 	data->valign = valign;
 	window_mark_dirty(label);
 
@@ -419,6 +457,25 @@ static void delete_label_data(window_t *label)
 	window_set_data(label, NULL);
 }
 
+void label_set_text(window_t *label, char *text)
+{
+	label_t *data;
+
+	if(window_get_type(label) != WINDOW_LABEL) {
+		return;
+	}
+
+	if(! (data = (label_t *)window_get_data(label)) ) {
+		return;
+	}
+
+	free(data->text);
+	data->text = (char *)strdup(text);
+    
+    window_mark_dirty(label);
+
+}
+
 /*
  * Local Variables:
  *  indent-tabs-mode:nil
