@@ -3,8 +3,8 @@
  *
  *   (C) 2004 Dominic Morris
  *
- *   $Id: windowlive.c,v 1.6 2004/05/17 07:18:09 ravelox Exp $
- *   $Date: 2004/05/17 07:18:09 $
+ *   $Id: windowlive.c,v 1.9 2004/08/30 11:21:05 ravelox Exp $
+ *   $Date: 2004/08/30 11:21:05 $
  *
  *
  *   Implements the skeleton application
@@ -96,20 +96,20 @@ static int program_open(dongle_t *dongle, application_t *application)
     window_set_name(program->root,"ROOT");
     surface_clear(window_get_draw_surface(program->root),0x00000000);
 	program->sub = new_box(program->root, 100,100, 300,300);
-	box_set_fill_col(program->sub, 0x00FF00);
-	box_set_border_col(program->sub, 0xFF0000);
-	box_set_border_size(program->sub, 20); 
+	window_set_fill_col(program->sub, 0x00FF00);
+	window_set_border_col(program->sub, 0xFF0000);
+	window_set_border_size(program->sub, 20); 
 	window_set_name(program->sub, "Box");
 
 	label = new_label(program->sub, 50,50, 200,200, "Hello\nWorld");
-	label_set_fgcol(label, 0xFFFFFF);
-	label_set_bgcol(label, 0x0000DD);
-	label_set_align(label, LABEL_ALIGN_CENTER);
+	window_set_fgcol(label, 0xFFFFFF);
+	window_set_bgcol(label, 0x0000DD);
+	label_set_align(label, LABEL_ALIGN_CENTRE);
 	label_set_valign(label, LABEL_VALIGN_MIDDLE);
 	window_set_name(label, "Label");
 
 	box = new_box(program->root, 200,200,300,300);
-	box_set_fill_col(box, 0x0000FF);
+	window_set_fill_col(box, 0x0000FF);
 	window_set_name(box, "New Box");
 
     return 0;
@@ -143,8 +143,7 @@ static uint8_t *program_get_surface(application_t *application, int *size)
     surface_t  *sfc = window_get_draw_surface(program->root);
 
     if( window_draw(program->root) > 0) {
-		*size = surface_get_yuvsize(sfc);
-		return (uint8_t *) surface_rgb2yvuy(sfc);  
+		return (uint8_t *) surface_map(sfc,MAP_YVU,size);  
 	}
 
 	return NULL;
@@ -184,10 +183,10 @@ static void program_keypress(application_t *application, int keycode)
 	case keyBlank:
 		fprintf(stderr, "zorder flag: %d\n", zorder);
 		if(zorder == 0) {
-			window_bring_forward(box);
+			window_set_focus(program->sub);
 			zorder = 1;
 		} else {
-			window_send_backward(box);
+			window_set_focus(box);
 			zorder = 0;
 		}
 		break;
@@ -196,8 +195,8 @@ static void program_keypress(application_t *application, int keycode)
 		label_set_align(label, LABEL_ALIGN_LEFT);
 		break;
 	 case key2:
-		fprintf(stderr, "Label: CENTER\n");
-		label_set_align(label, LABEL_ALIGN_CENTER);
+		fprintf(stderr, "Label: CENTRE\n");
+		label_set_align(label, LABEL_ALIGN_CENTRE);
 		break;
 	 case key3:
 		fprintf(stderr, "Label: RIGHT\n");
